==> web2sms_0.1.0.tar.gz: web2sms-0.1.0/src/translations/web2sms_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de_DE">
<context>
    <name>AccountSettingsDialog</name>
    <message>
        <location filename="../providers/accountsettingsdialog.ui" line="14"/>
        <source>Account settings</source>
        <translation>Konto Einstellungen</translation>
    </message>
    <message>
        <location filename="../providers/accountsettingsdialog.ui" line="22"/>
        <source>Username:</source>
        <translation>Benutzername:</translation>
    </message>
    <message>
        <location filename="../providers/accountsettingsdialog.ui" line="32"/>
        <source>Password:</source>
        <translation>Kennwort:</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>o2 Web2SMS</source>
        <translation type="obsolete">o2 Web2SMS</translation>
    </message>
    <message>
        <source>To:</source>
        <translation type="obsolete">An:</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation type="obsolete">&amp;Senden</translation>
    </message>
    <message>
        <source>Select provider</source>
        <translation type="obsolete">Anbieter auswählen</translation>
    </message>
    <message>
        <source>Account settings</source>
        <translation type="obsolete">Konto Einstellungen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="179"/>
        <source>First start notice</source>
        <translation>Erststart Hinweis</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="179"/>
        <source>This program only works with o2 Germany. Use at your own risk, bugs may be reported on the project website.</source>
        <translation>Dieses Programm funktioniert derzeit nur mit o2 Deutschland. Benutzung auf eigene Gefahr, Fehler können auf der Projekt-Webseite gemeldet werden.</translation>
    </message>
    <message>
        <source>Login failed, please check your username and password</source>
        <translation type="obsolete">Anmeldung fehlgeschlagen, bitte überprüfen Sie Ihre Angaben</translation>
    </message>
    <message>
        <source>Logging in ...</source>
        <translation type="obsolete">Anmeldung ...</translation>
    </message>
    <message>
        <source>Feature not implemented on Windows</source>
        <translation type="obsolete">Diese Funktion ist unter Windows nicht eingebaut</translation>
    </message>
    <message>
        <source>Logging in</source>
        <translation type="obsolete">Anmeldung ...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="200"/>
        <source>Logging out ...</source>
        <translation>Abmeldung ...</translation>
    </message>
    <message>
        <source>Feature not implemented on windows</source>
        <translation type="obsolete">Diese Funktion ist unter Windows nicht eingebaut</translation>
    </message>
    <message>
        <source>Choose a contact</source>
        <translation type="obsolete">Wählen Sie einen Kontakt</translation>
    </message>
    <message>
        <source>Sending SMS ...</source>
        <translation type="obsolete">Sende SMS ...</translation>
    </message>
    <message>
        <source>You have %1 free SMS left</source>
        <translation type="obsolete">Sie haben %1 Frei-SMS übrig</translation>
    </message>
</context>
<context>
    <name>MainWindowPrivate</name>
    <message>
        <location filename="../mainwindow.cpp" line="91"/>
        <source>Account settings</source>
        <translation>Konto Einstellungen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="92"/>
        <source>Select provider</source>
        <translation>Anbieter auswählen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="106"/>
        <source>Logging in ...</source>
        <translation>Anmeldung ...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="123"/>
        <source>Login failed, please check your username and password</source>
        <translation>Anmeldung fehlgeschlagen, bitte überprüfen Sie Ihre Angaben</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="151"/>
        <source>Currently there is only o2 Germany :(</source>
        <translation>Derzeit steht leider nur o2 Deutschland zur Auswahl :(</translation>
    </message>
</context>
<context>
    <name>MessageWidget</name>
    <message>
        <location filename="../messagewidget.ui" line="14"/>
        <source>Message</source>
        <translation>Nachricht</translation>
    </message>
    <message>
        <location filename="../messagewidget.ui" line="22"/>
        <source>To:</source>
        <translation>An:</translation>
    </message>
    <message>
        <location filename="../messagewidget.ui" line="37"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:8pt;&quot;&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../messagewidget.ui" line="80"/>
        <source>&amp;Send</source>
        <translation>&amp;Senden</translation>
    </message>
</context>
<context>
    <name>MessageWidgetPrivate</name>
    <message numerus="yes">
        <location filename="../messagewidget.cpp" line="112"/>
        <source>You have %n free SMS left</source>
        <translation>
            <numerusform>Sie haben eine Frei-SMS übrig</numerusform>
            <numerusform>Sie haben %n Frei-SMS übrig</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../messagewidget.cpp" line="119"/>
        <source>Choose a contact</source>
        <translation>Wählen Sie einen Kontakt</translation>
    </message>
    <message>
        <location filename="../messagewidget.cpp" line="146"/>
        <source>Sending SMS ...</source>
        <translation>Sende SMS ...</translation>
    </message>
</context>
<context>
    <name>contacts_windows</name>
    <message>
        <location filename="../contacts_windows.cpp" line="59"/>
        <source>Feature not implemented on Windows</source>
        <translation>Diese Funktion ist unter Windows nicht eingebaut</translation>
    </message>
</context>
<context>
    <name>o2Germany</name>
    <message>
        <location filename="../providers/o2_germany/o2_germany.cpp" line="432"/>
        <source>o2 Germany</source>
        <translation>o2 Deutschland</translation>
    </message>
</context>
<context>
    <name>o2GermanyPrivate</name>
    <message>
        <location filename="../providers/o2_germany/o2_germany.cpp" line="199"/>
        <source>loginForm could not be found!</source>
        <translation>loginForm konnte nicht gefunden werden!</translation>
    </message>
    <message>
        <location filename="../providers/o2_germany/o2_germany.cpp" line="314"/>
        <source>frmSMS could not be found!</source>
        <translation>frmSMS konnte nicht gefunden werden!</translation>
    </message>
    <message>
        <location filename="../providers/o2_germany/o2_germany.cpp" line="370"/>
        <source>HTTP error happened:
%1</source>
        <translation>HTTP Fehler aufgetreten:
%1</translation>
    </message>
</context>
</TS>

==> web2sms_0.1.1-4.tar.gz: web2sms-0.1.1/src/translations/web2sms_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de_DE">
<context>
    <name>AccountSettingsDialog</name>
    <message>
        <location filename="../providers/accountsettingsdialog.ui" line="14"/>
        <source>Account settings</source>
        <translation>Konto Einstellungen</translation>
    </message>
    <message>
        <location filename="../providers/accountsettingsdialog.ui" line="22"/>
        <source>Username:</source>
        <translation>Benutzername:</translation>
    </message>
    <message>
        <location filename="../providers/accountsettingsdialog.ui" line="32"/>
        <source>Password:</source>
        <translation>Kennwort:</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>o2 Web2SMS</source>
        <translation type="obsolete">o2 Web2SMS</translation>
    </message>
    <message>
        <source>To:</source>
        <translation type="obsolete">An:</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation type="obsolete">&amp;Senden</translation>
    </message>
    <message>
        <source>Select provider</source>
        <translation type="obsolete">Anbieter auswählen</translation>
    </message>
    <message>
        <source>Account settings</source>
        <translation type="obsolete">Konto Einstellungen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="182"/>
        <source>First start notice</source>
        <translation>Erststart Hinweis</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="182"/>
        <source>This program only works with o2 Germany. Use at your own risk, bugs may be reported on the project website.</source>
        <translation>Dieses Programm funktioniert derzeit nur mit o2 Deutschland. Benutzung auf eigene Gefahr, Fehler können auf der Projekt-Webseite gemeldet werden.</translation>
    </message>
    <message>
        <source>Login failed, please check your username and password</source>
        <translation type="obsolete">Anmeldung fehlgeschlagen, bitte überprüfen Sie Ihre Angaben</translation>
    </message>
    <message>
        <source>Logging in ...</source>
        <translation type="obsolete">Anmeldung ...</translation>
    </message>
    <message>
        <source>Feature not implemented on Windows</source>
        <translation type="obsolete">Diese Funktion ist unter Windows nicht eingebaut</translation>
    </message>
    <message>
        <source>Logging in</source>
        <translation type="obsolete">Anmeldung ...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="203"/>
        <source>Logging out ...</source>
        <translation>Abmeldung ...</translation>
    </message>
    <message>
        <source>Feature not implemented on windows</source>
        <translation type="obsolete">Diese Funktion ist unter Windows nicht eingebaut</translation>
    </message>
    <message>
        <source>Choose a contact</source>
        <translation type="obsolete">Wählen Sie einen Kontakt</translation>
    </message>
    <message>
        <source>Sending SMS ...</source>
        <translation type="obsolete">Sende SMS ...</translation>
    </message>
    <message>
        <source>You have %1 free SMS left</source>
        <translation type="obsolete">Sie haben %1 Frei-SMS übrig</translation>
    </message>
</context>
<context>
    <name>MainWindowPrivate</name>
    <message>
        <location filename="../mainwindow.cpp" line="77"/>
        <source>Web2SMS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="94"/>
        <source>Account settings</source>
        <translation>Konto Einstellungen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="95"/>
        <source>Select provider</source>
        <translation>Anbieter auswählen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="109"/>
        <source>Logging in ...</source>
        <translation>Anmeldung ...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="126"/>
        <source>Login failed, please check your username and password</source>
        <translation>Anmeldung fehlgeschlagen, bitte überprüfen Sie Ihre Angaben</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="154"/>
        <source>Currently there is only o2 Germany :(</source>
        <translation>Derzeit steht leider nur o2 Deutschland zur Auswahl :(</translation>
    </message>
</context>
<context>
    <name>MessageWidget</name>
    <message>
        <location filename="../messagewidget.ui" line="14"/>
        <source>Message</source>
        <translation>Nachricht</translation>
    </message>
    <message>
        <location filename="../messagewidget.ui" line="22"/>
        <source>To:</source>
        <translation>An:</translation>
    </message>
    <message>
        <location filename="../messagewidget.ui" line="37"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:8pt;&quot;&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../messagewidget.ui" line="96"/>
        <source>&amp;Send</source>
        <translation>&amp;Senden</translation>
    </message>
</context>
<context>
    <name>MessageWidgetPrivate</name>
    <message numerus="yes">
        <location filename="../messagewidget.cpp" line="113"/>
        <source>You have %n free SMS left</source>
        <translation>
            <numerusform>Sie haben eine Frei-SMS übrig</numerusform>
            <numerusform>Sie haben %n Frei-SMS übrig</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../messagewidget.cpp" line="120"/>
        <source>Choose a contact</source>
        <translation>Wählen Sie einen Kontakt</translation>
    </message>
    <message>
        <location filename="../messagewidget.cpp" line="129"/>
        <source>Wrong number format</source>
        <translation>Falsches Nummernformat</translation>
    </message>
    <message>
        <location filename="../messagewidget.cpp" line="130"/>
        <source>%1&apos;s phone number &quot;%2&quot; could not be converted to an international format.</source>
        <translation>Die Telefonnummer &quot;%2&quot; von %1 konnte nicht in ein internationales Format umgewandelt werden.</translation>
    </message>
    <message>
        <location filename="../messagewidget.cpp" line="156"/>
        <source>Sending SMS ...</source>
        <translation>Sende SMS ...</translation>
    </message>
</context>
<context>
    <name>contacts_windows</name>
    <message>
        <location filename="../contacts_windows.cpp" line="59"/>
        <source>Feature not implemented on Windows</source>
        <translation>Diese Funktion ist unter Windows nicht eingebaut</translation>
    </message>
</context>
<context>
    <name>o2Germany</name>
    <message>
        <location filename="../providers/o2_germany/o2_germany.cpp" line="432"/>
        <source>o2 Germany</source>
        <translation>o2 Deutschland</translation>
    </message>
</context>
<context>
    <name>o2GermanyPrivate</name>
    <message>
        <location filename="../providers/o2_germany/o2_germany.cpp" line="199"/>
        <source>loginForm could not be found!</source>
        <translation>loginForm konnte nicht gefunden werden!</translation>
    </message>
    <message>
        <location filename="../providers/o2_germany/o2_germany.cpp" line="314"/>
        <source>frmSMS could not be found!</source>
        <translation>frmSMS konnte nicht gefunden werden!</translation>
    </message>
    <message>
        <location filename="../providers/o2_germany/o2_germany.cpp" line="370"/>
        <source>HTTP error happened:
%1</source>
        <translation>HTTP Fehler aufgetreten:
%1</translation>
    </message>
</context>
</TS>
